@@ -26,6 +26,7 @@
 -- Mar 27 2011: Added CVM patch from Adam Laurie.
 -- Jan 23 2012: Added UK Post Office Card Account in AID list from Tyson Key.
 -- Mar 25 2012: Added a few AIDs
+-- @update: Feb 21 2014: Better NFC compatibility by using current date in GPO.
 
 require('lib.tlv')
 require('lib.strict')
@@ -54,7 +55,7 @@ function build_empty_pdol_data_block(pdol)
             data = data .. "0978"
         elseif o_tag==0x9A and o_len==3 then
             -- Transaction date
-            data = data .. "01 01 01"
+            data = data .. os.date("%y %m %d")
         elseif o_tag==0x9F37 and o_len==4 then
             -- Unpredictable number
             data = data .. "DEADBEEF"
@@ -127,13 +128,20 @@ function ui_parse_CVM(node,data)
 				val=bytes.sub(data,4,7)})
 
 	for i= 4,(#data/2)-1 do
+		left = data:get(i*2)
+		right = data:get(i*2+1)
+
+		if left == 0 and right == 0 then
+			-- Amex pads the list with zeroes at the end
+			-- Once we reach the zeroes, we're done parsing
+			break
+		end
+		
 		subnode = nodes.append(node, { classname="item",
 						   label="CVM",
 						   id=i-3,
 						   size=2,
 						   val=bytes.sub(data,i*2,i*2+1)})
-		left = data:get(i*2)
-		right = data:get(i*2+1)
 
 		if bit.AND(left,0x40) == 0x40 then
 			out = "Apply succeeding CV rule if this rule is unsuccessful: "
@@ -320,10 +328,10 @@ function emv_process_ppse(cardenv)
 
 	AID_LIST = {}
 
-	for dirent in  nodes.find(APP,{ id="4F" }) do
-	        aid = tostring(nodes.get_attribute(dirent,"val"))
+	for dirent in nodes.find(APP,{ id="4F" }) do
+	    aid = tostring(nodes.get_attribute(dirent,"val"))
 		log.print(log.INFO,"PPSE contains application #" .. aid)
-	        table.insert(AID_LIST,"#"..aid)
+	    table.insert(AID_LIST,"#"..aid)
 	end
 	return true
 
@@ -358,8 +366,8 @@ function emv_process_pse(cardenv)
 	end
 
 	if sw ~= 0x9000 then
-     	   log.print(log.INFO,"No PSE")
-	   return false
+        log.print(log.INFO,"No PSE")
+	    return false
 	end
 
 	-- Construct tree
@@ -368,24 +376,23 @@ function emv_process_pse(cardenv)
 
 	ref = nodes.find_first(APP,{id="88"})
 	if (ref) then
-	   sfi = nodes.get_attribute(ref,"val")
-	   FILE = nodes.append(APP,{classname="file", label="file", id=sfi[0]})
+        sfi = nodes.get_attribute(ref,"val")
+	    FILE = nodes.append(APP,{classname="file", label="file", id=sfi[0]})
 
-	   rec = 1
-	   AID_LIST = {}
-	   repeat 
-	     sw,resp = card.read_record(sfi:get(0),rec)
-	     if sw == 0x9000 then
-	        RECORD = nodes.append(FILE, {classname="record", label="record", id=tostring(rec)})
-	        emv_parse(RECORD,resp)
-		tag4F = nodes.find_first(RECORD,{id="4F"})
-		if (tag4F) then
-	           aid = tostring(nodes.get_attribute(tag4F,"val"))
-		   log.print(log.INFO,"PSE contains application #" .. aid)
-	           table.insert(AID_LIST,"#"..aid)
-		   rec = rec + 1
-		end
-             end
+	    rec = 1
+	    AID_LIST = {}
+	    repeat 
+            sw,resp = card.read_record(sfi:get(0),rec)
+	        if sw == 0x9000 then
+	            RECORD = nodes.append(FILE, {classname="record", label="record", id=tostring(rec)})
+	            emv_parse(RECORD,resp)
+                for tag4F in nodes.find(RECORD,{id="4F"}) do
+	                aid = tostring(nodes.get_attribute(tag4F,"val"))
+		            log.print(log.INFO,"PSE contains application #" .. aid)
+	                table.insert(AID_LIST,"#"..aid)
+		        end
+                rec = rec + 1
+            end
 	   until sw ~= 0x9000
 	else
 	   log.print(log.WARNING,"SFI indicator (tag 88) not found in PSE")
@@ -631,8 +638,14 @@ function emv_process_application(cardenv,aid)
 				log.print(log.INFO,string.format("Reading SFI %i, record %i",sfi_index, rec_index))
 			        sw,resp = card.read_record(sfi_index,rec_index)
 		                if sw ~= 0x9000 then
-			            log.print(log.WARNING,string.format("Read record failed for SFI %i, record %i",sfi_index,rec_index))
-				    break
+	                                  log.print(log.WARNING,string.format("Read record failed for SFI %i, record %i",sfi_index,rec_index))
+
+                                    -- Amex has files where records don't start at 1
+                                    -- The highest starting number I've seen is 4, 
+                                    -- so don't treat a failure of a lower-than-five record number as "end of records in a file"
+                                    if rec_index > 5 then
+					    break
+				    end
 			        else
 				    if (SFI==nil) then
 	   		    		    SFI = nodes.append(APP,{classname="file", label="file",	id=sfi_index})
