@@ -2,7 +2,7 @@
 *
 * This file is part of Cardpeek, the smart card reader utility.
 *
-* Copyright 2009-2013 by Alain Pannetrat <L1L1@gmx.com>
+* Copyright 2009-2014 by Alain Pannetrat <L1L1@gmx.com>
 *
 * Cardpeek is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -94,7 +94,6 @@ static void menu_cardview_clear_cb(GtkWidget *w, gpointer user_data)
     UNUSED(user_data);
 
     dyntree_model_iter_remove(CARDTREE,NULL);
-    luax_run_command("card.CLA=0");
     log_printf(LOG_INFO,"Cleared card data tree");
 }
 
@@ -145,6 +144,33 @@ static void menu_cardview_save_as_cb(GtkWidget *w, gpointer user_data)
     }
 }
 
+static void menu_cardview_copy(GtkWidget *menuitem, gpointer userdata)
+{
+    GtkTreeSelection *selection;
+    GtkTreeIter iter;
+    GtkTreeModel *model;
+    char *text;
+    GtkClipboard *clipboard;
+    UNUSED(userdata);
+    UNUSED(menuitem);
+ 
+    selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(CARDVIEW));
+
+    if (gtk_tree_selection_get_selected(selection,&model,&iter))
+    {
+        text = dyntree_model_iter_to_text(DYNTREE_MODEL(model),&iter);
+        if (text)
+        {    
+            clipboard = gtk_clipboard_get(GDK_SELECTION_PRIMARY);
+            gtk_clipboard_set_text(clipboard,text,-1);
+            clipboard = gtk_clipboard_get(GDK_SELECTION_CLIPBOARD);
+            gtk_clipboard_set_text(clipboard,text,-1);
+            /* g_printf("%s",text); */
+            g_free(text);
+        }
+    }
+}
+
 static void menu_cardview_switch_column(void)
 {
     GtkTreeViewColumn *column2 = gtk_tree_view_get_column(GTK_TREE_VIEW(CARDVIEW),2);
@@ -201,11 +227,20 @@ static void menu_cardview_context_menu(GtkWidget *treeview, GdkEventButton *even
 /* Create a right click context menu */
 {
     GtkWidget *menu, *menuitem;
+    GtkWidget *menuitem_child;
     GtkTreeViewColumn *column2 = gtk_tree_view_get_column(GTK_TREE_VIEW(treeview),2);
     UNUSED(userdata);
 
     menu = gtk_menu_new();
 
+    /* Menu Item */
+    menuitem = gtk_menu_item_new_with_label("Copy");
+    g_signal_connect(menuitem, "activate",
+                     (GCallback) menu_cardview_copy, treeview);
+    menuitem_child = gtk_bin_get_child (GTK_BIN (menuitem));
+    gtk_accel_label_set_accel (GTK_ACCEL_LABEL (menuitem_child), GDK_KEY_c, GDK_CONTROL_MASK);
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
+
     /* Menu Item */
     menuitem = gtk_menu_item_new_with_label("Expand all");
     g_signal_connect(menuitem, "activate",
@@ -225,6 +260,8 @@ static void menu_cardview_context_menu(GtkWidget *treeview, GdkEventButton *even
         g_signal_connect(menuitem, "activate",
                          (GCallback) menu_cardview_context_menu_change_value_type, treeview);
     }
+    menuitem_child = gtk_bin_get_child (GTK_BIN (menuitem));
+    gtk_accel_label_set_accel (GTK_ACCEL_LABEL (menuitem_child), GDK_KEY_r, GDK_CONTROL_MASK);
     gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
 
 
@@ -235,6 +272,27 @@ static void menu_cardview_context_menu(GtkWidget *treeview, GdkEventButton *even
                    gdk_event_get_time((GdkEvent *)event));
 }
 
+static gboolean menu_cardview_key_press_event(GtkWidget *treeview,  GdkEventKey *event, gpointer user_data)
+{
+    UNUSED(user_data);
+
+    if ((event->state&GDK_CONTROL_MASK)!=0)
+    {
+        if (event->keyval == GDK_KEY_c)
+        {
+            menu_cardview_copy(treeview,user_data);
+            return TRUE;
+        }
+        if (event->keyval == GDK_KEY_r)
+        {
+            menu_cardview_context_menu_change_value_type(treeview,user_data);
+            return TRUE;
+        }
+
+    }
+    return FALSE;
+}
+
 static gboolean menu_cardview_button_press_event(GtkWidget *treeview, GdkEventButton *event, gpointer userdata)
 {
     GtkTreeSelection *selection;
@@ -326,7 +384,7 @@ static void menu_cardview_analyzer_load_cb(GtkWidget *w, gpointer user_data)
 /* CONSTRUTION OF MAIN UI ********************************/
 /*********************************************************/
 
-static int select_lua(DIRENT_T *de)
+static int select_lua(const struct dirent *de)
 {
     char *ext=rindex(de->d_name,'.');
     if (ext && strcmp(ext,".lua")==0)
@@ -666,6 +724,9 @@ GtkWidget *gui_cardview_create_window(GtkAccelGroup *accel_group)
     g_signal_connect(CARDVIEW,
                      "button-press-event", (GCallback) menu_cardview_button_press_event, NULL);
 
+    g_signal_connect(CARDVIEW,
+                     "key-press-event", (GCallback) menu_cardview_key_press_event, NULL);
+
 
     gtk_container_add (GTK_CONTAINER (scrolled_window), CARDVIEW);
 
