@@ -2,7 +2,7 @@
 *
 * This file is part of Cardpeek, the smart card reader utility.
 *
-* Copyright 2009-2013 by Alain Pannetrat <L1L1@gmx.com>
+* Copyright 2009-2014 by Alain Pannetrat <L1L1@gmx.com>
 *
 * Cardpeek is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 
 const char *PATH_CONFIG_OPTIONS[NUM_PATH_CONFIG_OPTIONS]=
 {
+    NULL,
     NULL,
     NULL,
     "",
@@ -39,7 +40,8 @@ const char *PATH_CONFIG_OPTIONS[NUM_PATH_CONFIG_OPTIONS]=
     "cardpeekrc.lua",
     "version",
     "scripts/etc/smartcard_list.txt",
-    "scripts/etc/smartcard_list.download"
+    "scripts/etc/smartcard_list.download",
+    "cardpeek.update"
 };
 
 char *PATH_CONFIG_STRING[NUM_PATH_CONFIG_OPTIONS];
@@ -57,8 +59,8 @@ int path_config_init(void)
     home_dir = getenv("HOME");
 #else
     home_dir = getenv("USERDATA");
-        if (home_dir==NULL)
-            home_dir = getenv("USERPROFILE");
+    if (home_dir==NULL)
+        home_dir = getenv("USERPROFILE");
 #endif
     if (home_dir==NULL)
         return 0;
@@ -76,7 +78,9 @@ int path_config_init(void)
     snprintf(path_config_string,PATH_MAX,"%s/.cardpeek.log",home_dir);
     PATH_CONFIG_STRING[1]=strdup(path_config_string);
 
-    for (i=2; i<NUM_PATH_CONFIG_OPTIONS; i++)
+    PATH_CONFIG_STRING[2]=strdup(home_dir);
+
+    for (i=PATH_CONFIG_FOLDER_CARDPEEK; i<NUM_PATH_CONFIG_OPTIONS; i++)
     {
         snprintf(path_config_string,PATH_MAX,"%s/%s",cardpeek_dir,PATH_CONFIG_OPTIONS[i]);
         PATH_CONFIG_STRING[i]=strdup(path_config_string);
